package com.qs.mp.channel.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.qs.mp.channel.domain.ChannelOrderDetail;
import com.qs.mp.channel.domain.ChannelTicketTransfer;
import com.qs.mp.channel.domain.param.ChannelTicketTransferParam;
import com.qs.mp.channel.mapper.ChannelTicketTransferMapper;
import com.qs.mp.channel.service.IChannelOrderDetailService;
import com.qs.mp.channel.service.IChannelTicketTransferService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * <p>
 * 经销商盲票转让信息表 服务实现类
 * </p>
 *
 * @author quanshu
 * @since 2022-04-21
 */
@Service
public class ChannelTicketTransferServiceImpl extends ServiceImpl<ChannelTicketTransferMapper, ChannelTicketTransfer> implements IChannelTicketTransferService {


    @Autowired
    private IChannelOrderDetailService channelOrderDetailService;


    @Override
    @Transactional(rollbackFor = Exception.class)
    public boolean transferTicket(Long transferChannelId, ChannelTicketTransferParam channelTicketTransferParam) {

        // 转让盲票
        ChannelTicketTransfer channelTicketTransfer = new ChannelTicketTransfer();
        channelTicketTransfer.setTransferChannelId(transferChannelId);
        channelTicketTransfer.setChannelId(channelTicketTransferParam.getChannelId());
        channelTicketTransfer.setBoxId(channelTicketTransferParam.getBoxId());
        channelTicketTransfer.setPkgId(channelTicketTransferParam.getPkgId());

        // 更新盲票拥有人信息
        ChannelOrderDetail channelOrderDetail = new ChannelOrderDetail();
        channelOrderDetail.setPkgId(channelTicketTransferParam.getPkgId());
        channelOrderDetail.setChannelId(channelTicketTransferParam.getChannelId());

        // 记录盲票转让信息
        this.save(channelTicketTransfer);

        // 更新盲票拥有人
        channelOrderDetailService.update(new LambdaUpdateWrapper<ChannelOrderDetail>()
                .set(ChannelOrderDetail::getChannelId, channelTicketTransferParam.getChannelId())
                .eq(ChannelOrderDetail::getPkgId, channelTicketTransferParam.getPkgId())
                .eq(ChannelOrderDetail::getChannelId, transferChannelId));

        return true;
    }
}
